BlocErrorData class
Snapshot of a BLoC / Cubit onError invocation.
Constructors
- BlocErrorData({required BlocBase bloc, required Object error, required StackTrace stackTrace})
Properties
- bloc → BlocBase
-
final
- blocType → String
-
no setter
- error → Object
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Returns a raw, JSON-compatible map of the error event.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited